==> eslint_5.0.1~dfsg.orig.tar.xz: eslint-5.0.1/tests/lib/rules/no-floating-decimal.js <==
/**
 * @fileoverview Tests for no-floating-decimal rule.
 * @author James Allardice
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-floating-decimal"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();

ruleTester.run("no-floating-decimal", rule, {
    valid: [
        "var x = 2.5;",
        "var x = \"2.5\";"
    ],
    invalid: [
        {
            code: "var x = .5;",
            output: "var x = 0.5;",
            errors: [{ message: "A leading decimal point can be confused with a dot.", type: "Literal" }]
        },
        {
            code: "var x = -.5;",
            output: "var x = -0.5;",
            errors: [{ message: "A leading decimal point can be confused with a dot.", type: "Literal" }]
        },
        {
            code: "var x = 2.;",
            output: "var x = 2.0;",
            errors: [{ message: "A trailing decimal point can be confused with a dot.", type: "Literal" }]
        },
        {
            code: "var x = -2.;",
            output: "var x = -2.0;",
            errors: [{ message: "A trailing decimal point can be confused with a dot.", type: "Literal" }]
        },
        {
            code: "typeof.2",
            output: "typeof 0.2",
            errors: [{ message: "A leading decimal point can be confused with a dot.", type: "Literal" }]
        },
        {
            code: "for(foo of.2);",
            output: "for(foo of 0.2);",
            parserOptions: { ecmaVersion: 2015 },
            errors: [{ message: "A leading decimal point can be confused with a dot.", type: "Literal" }]
        }
    ]
});

==> eslint_5.16.0~dfsg+~4.16.8.orig.tar.xz: eslint-5.16.0/tests/lib/rules/no-floating-decimal.js <==
/**
 * @fileoverview Tests for no-floating-decimal rule.
 * @author James Allardice
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-floating-decimal"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();
const leadingError = { messageId: "leading", type: "Literal" };
const trailingError = { messageId: "trailing", type: "Literal" };

ruleTester.run("no-floating-decimal", rule, {
    valid: [
        "var x = 2.5;",
        "var x = \"2.5\";"
    ],
    invalid: [
        {
            code: "var x = .5;",
            output: "var x = 0.5;",
            errors: [leadingError]
        },
        {
            code: "var x = -.5;",
            output: "var x = -0.5;",
            errors: [leadingError]
        },
        {
            code: "var x = 2.;",
            output: "var x = 2.0;",
            errors: [trailingError]
        },
        {
            code: "var x = -2.;",
            output: "var x = -2.0;",
            errors: [trailingError]
        },
        {
            code: "typeof.2",
            output: "typeof 0.2",
            errors: [leadingError]
        },
        {
            code: "for(foo of.2);",
            output: "for(foo of 0.2);",
            parserOptions: { ecmaVersion: 2015 },
            errors: [leadingError]
        }
    ]
});
